abjad-ext-rmakers
=================

Abjad's rhythm-maker extension package.

![Build Status](
    https://github.com/Abjad/abjad-ext-rmakers/actions/workflows/main.yml/badge.svg)
[![Code style: black](
    https://img.shields.io/badge/code%20style-black-000000.svg)](
    https://github.com/ambv/black)
